You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ka...@apache.org on 2008/07/11 16:58:30 UTC

svn commit: r675977 - in /directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog: ChangeLogSearchEngine.java TagSearchEngine.java

Author: kayyagari
Date: Fri Jul 11 07:58:29 2008
New Revision: 675977

URL: http://svn.apache.org/viewvc?rev=675977&view=rev
Log:
replaced the NamingEnumeration with Cursor 

Modified:
    directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogSearchEngine.java
    directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/TagSearchEngine.java

Modified: directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogSearchEngine.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogSearchEngine.java?rev=675977&r1=675976&r2=675977&view=diff
==============================================================================
--- directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogSearchEngine.java (original)
+++ directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogSearchEngine.java Fri Jul 11 07:58:29 2008
@@ -20,9 +20,8 @@
 package org.apache.directory.server.core.changelog;
 
 
-import javax.naming.NamingEnumeration;
-
 import org.apache.directory.server.core.authn.LdapPrincipal;
+import org.apache.directory.server.core.cursor.Cursor;
 import org.apache.directory.shared.ldap.filter.ExprNode;
 import org.apache.directory.shared.ldap.ldif.ChangeType;
 import org.apache.directory.shared.ldap.name.LdapDN;
@@ -92,7 +91,7 @@
      * @return an enumeration of all the ChangeLogEvents
      * @throws Exception if there are failures accessing the store
      */
-    NamingEnumeration<ChangeLogEvent> find( RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> find( RevisionOrder order ) throws Exception;
 
 
     /**
@@ -105,7 +104,7 @@
      * @throws IllegalArgumentException if the revision is out of range (less than 0
      * and greater than the current revision)
      */
-    NamingEnumeration<ChangeLogEvent> findBefore( long revision, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> findBefore( long revision, RevisionOrder order ) throws Exception;
 
 
     /**
@@ -122,7 +121,7 @@
      * @throws IllegalArgumentException if the revision is out of range (less than 0
      * and greater than the current revision)
      */
-    NamingEnumeration<ChangeLogEvent> findAfter( long revision, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> findAfter( long revision, RevisionOrder order ) throws Exception;
 
 
     /**
@@ -136,7 +135,7 @@
      * @throws IllegalArgumentException if the start and end revisions are out of range
      * (less than 0 and greater than the current revision), or if startRevision > endRevision
      */
-    NamingEnumeration<ChangeLogEvent> find( long startRevision, long endRevision, RevisionOrder order )
+    Cursor<ChangeLogEvent> find( long startRevision, long endRevision, RevisionOrder order )
         throws Exception;
 
     
@@ -148,7 +147,7 @@
      * @return the set of changes that occurred on an entry
      * @throws Exception if there are failures accessing the store
      */
-    NamingEnumeration<ChangeLogEvent> find( LdapDN dn, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> find( LdapDN dn, RevisionOrder order ) throws Exception;
     
     
     /**
@@ -160,7 +159,7 @@
      * @return the set of changes that occurred on an entry and/or it's descendants depending on the scope
      * @throws Exception if there are failures accessing the store
      */
-    NamingEnumeration<ChangeLogEvent> find( LdapDN base, Scope scope, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> find( LdapDN base, Scope scope, RevisionOrder order ) throws Exception;
     
 
     /**
@@ -171,7 +170,7 @@
      * @return the set of changes that were triggered by a specific LDAP user
      * @throws Exception if there are failures accessing the store
      */
-    NamingEnumeration<ChangeLogEvent> find( LdapPrincipal principal, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> find( LdapPrincipal principal, RevisionOrder order ) throws Exception;
     
     
     /**
@@ -182,7 +181,7 @@
      * @return the set of ChangeLogEvents of a particular ChangeType
      * @throws Exception if there are failures accessing the store
      */
-    NamingEnumeration<ChangeLogEvent> find( ChangeType changeType, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> find( ChangeType changeType, RevisionOrder order ) throws Exception;
     
     
     /**
@@ -193,7 +192,7 @@
      * @return the set of ChangeLogEvents on a particular attributeType
      * @throws Exception if there are failures accessing the store
      */
-    NamingEnumeration<ChangeLogEvent> find( AttributeType attributeType, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> find( AttributeType attributeType, RevisionOrder order ) throws Exception;
     
 
     /**
@@ -204,7 +203,7 @@
      * @return the set of ChangeLogEvents on a particular attributeType
      * @throws Exception if there are failures accessing the store
      */
-    NamingEnumeration<ChangeLogEvent> find( ObjectClass objectClass, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> find( ObjectClass objectClass, RevisionOrder order ) throws Exception;
     
     
     /**
@@ -238,5 +237,5 @@
      * @return the set of ChangeLogEvents on entries of a particular objectClass
      * @throws Exception if there are failures accessing the store
      */
-    NamingEnumeration<ChangeLogEvent> find( ExprNode filter, RevisionOrder order ) throws Exception;
+    Cursor<ChangeLogEvent> find( ExprNode filter, RevisionOrder order ) throws Exception;
 }

Modified: directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/TagSearchEngine.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/TagSearchEngine.java?rev=675977&r1=675976&r2=675977&view=diff
==============================================================================
--- directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/TagSearchEngine.java (original)
+++ directory/apacheds/branches/bigbang/core/src/main/java/org/apache/directory/server/core/changelog/TagSearchEngine.java Fri Jul 11 07:58:29 2008
@@ -20,7 +20,7 @@
 package org.apache.directory.server.core.changelog;
 
 
-import javax.naming.NamingEnumeration;
+import org.apache.directory.server.core.cursor.Cursor;
 
 
 /**
@@ -81,10 +81,10 @@
      * revision.
      *
      * @param order the revision order in which to return snapshot tags 
      * @return an enumeration over the tags of all snapshots taken since revision 0
      * @throws Exception if there is a problem accessing the store
      */
-    NamingEnumeration<Tag> find( RevisionOrder order ) throws Exception;
+    Cursor<Tag> find( RevisionOrder order ) throws Exception;
     
     /**
      * Finds all the snapshot tags taken before a specific revision.  If a tag 
@@ -97,7 +97,7 @@
      * @throws IllegalArgumentException if the revision is greater than the current revision
      * or less than 0.
      */
-    NamingEnumeration<Tag> findBefore( long revision, RevisionOrder order ) throws Exception;
+    Cursor<Tag> findBefore( long revision, RevisionOrder order ) throws Exception;
     
     /**
      * Finds all the snapshot tags taken after a specific revision.  If a tag 
@@ -110,7 +110,7 @@
      * @throws IllegalArgumentException if the revision is greater than the current revision
      * or less than 0.
      */
-    NamingEnumeration<Tag> findAfter( long revision, RevisionOrder order ) throws Exception;
+    Cursor<Tag> findAfter( long revision, RevisionOrder order ) throws Exception;
     
     /**
      * Enumerates over the tags of all snapshots taken between a specific revision 
@@ -125,6 +125,6 @@
      * @throws IllegalArgumentException if the revision range is not constructed properly
      * or if either revision number is greater than the current revision or less than 0.
      */
-    NamingEnumeration<Tag> find( long startRevision, long endRevision, RevisionOrder order ) 
+    Cursor<Tag> find( long startRevision, long endRevision, RevisionOrder order ) 
         throws Exception;
 }
@@ -81,10 +81,10 @@
      *
      * @param order the revision order in which to return snapshot tags 
-     * @return an enumeration over the tags of all snapshots taken since revision 0
+     * @return a cursor containing the tags of all snapshots taken since revision 1
      * @throws Exception if there is a problem accessing the store
      */